@@ -19,8 +19,8 @@ def extract_message(text):
 def get_diff(gh_before, sha):
     return subprocess.check_output(['git', 'diff', gh_before, sha, "--word-diff"]).decode('utf-8')
 
-def review(openai_key, assistant_id, token, repo, message, gh_before, sha, author, webhook, websecret):
-    git_publisher = GitIssuePublisher(repo, token, sha, author)
+def review(openai_key, assistant_id, token, repo, branch, message, gh_before, sha, webhook, websecret):
+    git_publisher = GitIssuePublisher(token, repo, branch, sha)
     web_publisher = WebPublisher(webhook, websecret)
 
     try:
@@ -79,14 +79,12 @@ def main():
     parser.add_argument('--assistant-id', default=os.getenv('OPENAI_ASSISTANT_ID'), help='OpenAI assistant ID')
     parser.add_argument('--token', default=os.getenv('GH_TOKEN'), help='GitHub token')
 
-    #### Commit id versions
-    parser.add_argument('--gh-before', default=os.getenv('GH_BEFORE'), help='GitHub before SHA')
-    parser.add_argument('--sha', default=os.getenv('SHA'), help='Commit SHA')
-
     #### Data of commit
     parser.add_argument('--repo', default=os.getenv('REPO'), help='Repository name')
+    parser.add_argument('--branch', default=os.getenv('BRANCH'), help='Branch of work')
+    parser.add_argument('--gh-before', default=os.getenv('GH_BEFORE'), help='GitHub before SHA')
+    parser.add_argument('--sha', default=os.getenv('SHA'), help='Commit SHA')
     parser.add_argument('--message', default=os.getenv('MESSAGE'), help='Commit message')
-    parser.add_argument('--author', default=os.getenv('AUTHOR'), help='Commit author')
 
     #### External Api to post
     parser.add_argument('--webhook', default=os.getenv('WEBHOOK'), help='Webhook URL')
@@ -94,7 +92,7 @@ def main():
 
     args = parser.parse_args()
 
-    review(args.openai_key, args.assistant_id, args.token, args.repo, args.message, args.gh_before, args.sha, args.author, args.webhook, args.websecret)
+    review(args.openai_key, args.assistant_id, args.token, args.repo, args.branch, args.message, args.gh_before, args.sha, args.webhook, args.websecret)
 
 if __name__ == "__main__":
     main()
